@@ -1,26 +1,17 @@
 #' @title Easy planned contrasts
 #'
-#' @description Easily compute planned contrast analyses (pairwise
-#' comparisons similar to t-tests but more powerful when more than
-#' 2 groups), and format in publication-ready format. Supports only
-#' three groups for the moment. In this particular case, the
-#' confidence intervals are bootstraped on the Robust Cohen's d.
-#'
-#' @details Statistical power is lower with the standard *t* test
-#' compared than it is with the planned contrast version for two
-#' reasons: a) the sample size is smaller with the *t* test,
-#' because only the cases in the two groups are selected; and b)
-#' in the planned contrast the error term is smaller than it is
-#' with the standard *t* test because it is based on all the cases
-#' ([source](https://web.pdx.edu/~newsomj/uvclass/ho_planned%20contrasts.pdf)).
+#' @inherit nice_lm_contrasts description details return
 #'
 #' @param response The dependent variable.
 #' @param group The group for the comparison.
 #' @param covariates The desired covariates in the model.
 #' @param data The data frame.
+#' @param effect.type What effect size type to use. One of "cohens.d" (default),
+#' "akp.robust.d", "unstandardized", "hedges.g", "cohens.d.sigma", or "r".
 #' @param bootstraps The number of bootstraps to use for the confidence interval
+#' @param ... Arguments passed to [bootES::bootES].
 #' @keywords planned contrasts pairwise comparisons
-#' group differences internal
+#' group differences
 #' @return A dataframe, with the selected dependent variable(s), comparisons of
 #'         interest, degrees of freedom, t-values, p-values, robust Cohen's d
 #'         (dR), and the lower and upper 95% confidence intervals of the
@@ -57,12 +48,18 @@
 #' )
 #' }
 #' @seealso
+#' \code{\link{nice_lm_contrasts}},
 #' Tutorial: \url{https://rempsyc.remi-theriault.com/articles/contrasts}
 #'
 #' @importFrom dplyr %>% bind_rows
 
-nice_contrasts <- function(response, group, covariates = NULL,
-                           data, bootstraps = 2000) {
+nice_contrasts <- function(response,
+                           group,
+                           covariates = NULL,
+                           data,
+                           effect.type = "cohens.d",
+                           bootstraps = 2000,
+                           ...) {
   rlang::check_installed(c("bootES", "emmeans"), reason = "for this function.")
   data[[group]] <- as.factor(data[[group]])
   data[response] <- lapply(data[response], as.numeric)
@@ -85,28 +82,30 @@ nice_contrasts <- function(response, group, covariates = NULL,
     # Add support x groups
     comp3 = stats::setNames(c(1, -1, 0), levels(data[[group]]))
   )
+
   # Add support x groups
-  boot.lists <- lapply(groups.contrasts, function(y) {
+  es.lists <- lapply(groups.contrasts, function(y) {
     lapply(response, function(x) {
       bootES::bootES(
-        data = stats::na.omit(data),
+        data = stats::na.omit(data[, c(group, x)]),
         R = bootstraps,
         data.col = x,
         group.col = group,
         contrast = y,
-        effect.type = "akp.robust.d"
+        effect.type = effect.type,
+        ...
       )
     })
   })
+
   contrval.list <- lapply(leastsquare.list, emmeans::contrast,
     groups.contrasts,
     adjust = "none"
   )
   contrval.sums <- lapply(contrval.list, summary)
-  # boot.sums <- lapply(unlist(boot.lists, recursive = FALSE), summary)
 
   boot.sums <- lapply(seq(length(response)), function(y) {
-    lapply(boot.lists, function(x) {
+    lapply(es.lists, function(x) {
       as.data.frame(summary(x[[y]]))
         }) %>%
       bind_rows
@@ -117,10 +116,6 @@ nice_contrasts <- function(response, group, covariates = NULL,
     stats.list[[list.names[i]]] <- unlist(c(t((
       lapply(contrval.sums, `[[`, i + 1)))))
   }
-  # list.names2 <- c("cohenD", "cohenDL", "cohenDH")
-  # for (i in seq_along(list.names2)) {
-  #   stats.list[[list.names2[i]]] <- bind_rows(boot.sums)
-  # }
   response.names <- rep(response, each = length(contrval.sums[[1]]$contrast))
   comparisons.names <- rep(
     c(
@@ -145,12 +140,18 @@ nice_contrasts <- function(response, group, covariates = NULL,
     stats.list[-c(1:2)],
     bind_rows(boot.sums)[1:3]
   )
-  # table.stats <- table.stats[order(factor(table.stats$response.names,
-  #   levels = response
-  # )), ]
+
+  effect.name <- dplyr::case_when(
+    effect.type == "unstandardized" ~ "Mean difference",
+    effect.type == "cohens.d" ~ "d",
+    effect.type == "hedges.g" ~ "g",
+    effect.type == "cohens.d.sigma" ~ "d_sigma",
+    effect.type == "r" ~ "r",
+    effect.type == "akp.robust.d" ~ "dR")
+
   names(table.stats) <- c(
     "Dependent Variable", "Comparison", "df",
-    "t", "p", "dR", "CI_lower", "CI_upper"
+    "t", "p", effect.name, "CI_lower", "CI_upper"
   )
   row.names(table.stats) <- NULL
   table.stats
