@@ -3,8 +3,12 @@
 #' @description Formats output of `lm` model object for a
 #' publication-ready format.
 #'
-#' Note: this function uses the `modelEffectSizes` function
-#' from the `lmSupport` package to get the sr2 effect sizes.
+#' @details The effect size, sr2 (semi-partial correlation squared, also
+#' known as delta R2), is computed through [effectsize::r2_semipartial].
+#' Please read the documentation for that function, especially regarding
+#' the interpretation of the confidence interval. In `rempsyc`, instead
+#' of using the default one-sided alternative ("greater"), we use the
+#' two-sided alternative.
 #'
 #' @param model The model to be formatted.
 #' @param b.label What to rename the default "b" column (e.g.,
@@ -12,13 +16,16 @@
 #' to the Greek beta symbol in the `nice_table` function).
 #' @param mod.id Logical. Whether to display the model number,
 #' when there is more than one model.
+#' @param ci.alternative Alternative for the confidence interval
+#' of the sr2. It can be either "two.sided (the default in this
+#' package), "greater", or "less".
 #' @param ... Further arguments to be passed to the
-#' `lm` function for the models.
+#' [effectsize::r2_semipartial] function for the effect size.
 #'
 #' @keywords moderation interaction regression
 #' @return A formatted dataframe of the specified lm model, with DV, IV, degrees
-#'         of freedom, regression coefficient, t-value, p-value, and the effect
-#'         size, the semi-partial correlation squared.
+#' of freedom, regression coefficient, t-value, p-value, and the effect
+#' size, the semi-partial correlation squared, and its confidence interval.
 #' @export
 #' @examples
 #' # Make and format model
@@ -40,17 +47,21 @@
 nice_lm <- function(model,
                     b.label = "b",
                     mod.id = TRUE,
+                    ci.alternative = "two.sided",
                     ...) {
-  ifelse(class(model) == "list",
-    models.list <- model,
+  rlang::check_installed("effectsize", reason = "for this function.")
+  if (inherits(model, "list")) {
+    models.list <- model
+  } else {
     models.list <- list(model)
-  )
+  }
   sums.list <- lapply(models.list, function(x) {
     summary(x)$coefficients[-1, -2]
   })
-  df.list <- lapply(models.list, function(x) x[["df.residual"]])
+  df.list <- lapply(models.list, function(x) x["df.residual"])
   ES.list <- lapply(models.list, function(x) {
-    sr2(x)$sr2
+    z <- effectsize::r2_semipartial(x, alternative = ci.alternative, ...)
+    dplyr::select(z, "r2_semipartial", "CI_low", "CI_high")
   })
   stats.list <- mapply(cbind, df.list, sums.list, ES.list, SIMPLIFY = FALSE)
   stats.list <- lapply(stats.list, function(x) {
@@ -66,7 +77,7 @@ nice_lm <- function(model,
   table.stats <- cbind(response.names, table.stats)
   good.names <- c(
     "Dependent Variable", "Predictor",
-    "df", "b", "t", "p", "sr2"
+    "df", "b", "t", "p", "sr2", "CI_lower", "CI_upper"
   )
   if (length(models.list) > 1 & mod.id == TRUE) {
     model.number <- rep(seq_along(models.list), times = lapply(sums.list, nrow))
