@@ -44,7 +44,7 @@
 #' )
 #'
 #' # Can be passed some of the regular arguments
-#' # of base `t.test()`
+#' # of base [t.test()]
 #'
 #' # Student t-test (instead of Welch)
 #' nice_t_test(
@@ -78,8 +78,6 @@
 #' )
 #' # Make sure cases appear in the same order for
 #' # both levels of the grouping factor
-#' @importFrom methods hasArg
-#'
 #' @seealso
 #' Tutorial: \url{https://rempsyc.remi-theriault.com/articles/t-test}
 #'
@@ -90,19 +88,27 @@ nice_t_test <- function(data,
                         correction = "none",
                         warning = TRUE,
                         ...) {
+  rlang::check_installed(c("effectsize", "methods"),
+                         reason = "for this function.")
   args <- list(...)
-  if (hasArg(var.equal)) {
-    if (args$var.equal == TRUE) message_white("Using Student t-test. \n ")
-    if (args$var.equal == FALSE) message_white("Using Welch t-test. \n ")
+  if (methods::hasArg(var.equal)) {
+    if (isTRUE(args$var.equal)) {
+      message_white("Using Student t-test. \n ")
+    } else if (isFALSE(args$var.equal)) {
+      message_white("Using Welch t-test. \n ")
+    }
+    pooled_sd <- args$var.equal
+    } else {
+      pooled_sd <- TRUE
   }
-  if (hasArg(paired)) {
+  if (methods::hasArg(paired)) {
     paired <- args$paired
     if (paired == TRUE) message_white("Using paired t-test. \n ")
     if (paired == FALSE) message_white("Using independent samples t-test. \n ")
   } else {
     paired <- FALSE
   }
-  if (!hasArg(var.equal) & paired == FALSE & warning == TRUE) {
+  if (!methods::hasArg(var.equal) & paired == FALSE & warning == TRUE) {
     message_white(
       "Using Welch t-test (base R's default; ",
       "cf. https://doi.org/10.5334/irsp.82).
@@ -117,7 +123,7 @@ For the Student t-test, use `var.equal = TRUE`. \n "
     message_white("Using one-sample t-test. \n ")
     formulas <- lapply(data[response], as.numeric)
   }
-  if (hasArg(mu)) {
+  if (methods::hasArg(mu)) {
     mu <- args$mu
   } else {
     mu <- 0
@@ -127,13 +133,14 @@ For the Student t-test, use `var.equal = TRUE`. \n "
   sums.list <- lapply(mod.list, function(x) {
     (x)[list.names]
   })
-  lapply(formulas, function(x) {
+  boot.lists <- lapply(formulas, function(x) {
     effectsize::cohens_d(x,
       data = data,
       paired = paired,
-      mu = mu
+      mu = mu,
+      pooled_sd = pooled_sd
     )
-  }) -> boot.lists
+  })
   list.stats <- list()
   for (i in seq_along(list.names)) {
     list.stats[[list.names[i]]] <- unlist(c(t((lapply(sums.list, `[[`, i)))))
